Slots | Vue.js Modal
Description: Simple, flexible, Vue.js modal plugin

# # Slots

## # Close button

If you want to have a Close (x) button in the top-right corner, you can use "top-right" slot for it. There is no pre-defined Close button style - you will have to implement your own button.

    <template>
      <modal name="foo">
        <div slot="top-right">
          <button @click="$modal.hide('foo')">
            ❌
          </button>
        </div>
        Hello, ☀️!
      </modal>
    </template>